package sun.security.provider.certpath;

import java.util.HashMap;
import java.util.Collection;
import java.security.cert.X509CRLSelector;
import javax.security.auth.x500.X500Principal;
import java.security.cert.X509CertSelector;
import java.security.InvalidAlgorithmParameterException;
import java.security.cert.CertStore;
import java.net.URI;
import java.io.IOException;
import java.security.cert.CertStoreException;
import java.security.PrivilegedActionException;
import java.security.NoSuchAlgorithmException;
import java.security.AccessController;
import java.security.PrivilegedExceptionAction;
import sun.security.util.Cache;
import java.util.Map;

public abstract class CertStoreHelper
{
    private static final int NUM_TYPES = 2;
    private static final Map<String, String> classMap;
    private static Cache<String, CertStoreHelper> cache;
    
    public CertStoreHelper() {
    }
    
    public static CertStoreHelper getInstance(final String s) throws NoSuchAlgorithmException {
        CertStoreHelper certStoreHelper = (CertStoreHelper)CertStoreHelper.cache.get(s);
        if (certStoreHelper != null) {
            return certStoreHelper;
        }
        final String s2 = (String)CertStoreHelper.classMap.get(s);
        if (s2 == null) {
            throw new NoSuchAlgorithmException(s + " not available");
        }
        try {
            return (CertStoreHelper)AccessController.doPrivileged(new PrivilegedExceptionAction<CertStoreHelper>() {
                @Override
                public CertStoreHelper run() throws ClassNotFoundException {
                    try {
                        CertStoreHelper certStoreHelper = (CertStoreHelper)Class.forName(s2, true, null).newInstance();
                        CertStoreHelper.cache.put(s, certStoreHelper);
                        return certStoreHelper;
                    }
                    catch (InstantiationException | IllegalAccessException detailMessage) {
                        throw new AssertionError(detailMessage);
                    }
                }
            });
        }
        catch (PrivilegedActionException ex) {
            throw new NoSuchAlgorithmException(s + " not available", ex.getException());
        }
    }
    
    static boolean isCausedByNetworkIssue(String s, CertStoreException ex) {
        int n = -1;
        switch (s.hashCode()) {
            case 2331559: {
                if (s.equals("LDAP")) {
                    n = 0;
                    break;
                }
                break;
            }
            case 133315663: {
                if (s.equals("SSLServer")) {
                    n = 1;
                    break;
                }
                break;
            }
            case 84300: {
                if (s.equals("URI")) {
                    n = 2;
                    break;
                }
                break;
            }
        }
        switch (n) {
            case 0:
            case 1: {
                try {
                    return getInstance(s).isCausedByNetworkIssue(ex);
                }
                catch (NoSuchAlgorithmException ex2) {
                    return false;
                }
            }
            case 2: {
                Throwable cause = ex.getCause();
                return cause != null && cause instanceof IOException;
            }
            default: {
                return false;
            }
        }
    }
    
    public abstract CertStore getCertStore(URI p0) throws NoSuchAlgorithmException, InvalidAlgorithmParameterException;
    
    public abstract X509CertSelector wrap(X509CertSelector p0, X500Principal p1, String p2) throws IOException;
    
    public abstract X509CRLSelector wrap(X509CRLSelector p0, Collection<X500Principal> p1, String p2) throws IOException;
    
    public abstract boolean isCausedByNetworkIssue(CertStoreException p0);
    
    static {
        (classMap = new HashMap(2)).put("LDAP", "sun.security.provider.certpath.ldap.LDAPCertStoreHelper");
        CertStoreHelper.classMap.put("SSLServer", "sun.security.provider.certpath.ssl.SSLServerCertStoreHelper");
        CertStoreHelper.cache = Cache.newSoftMemoryCache(2);
    }
}
